netapp_ontap.models.cluster_peer_authentication API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.cluster_peer_authentication`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ClusterPeerAuthenticationSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ClusterPeerAuthentication object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `expiry_time: str GET POST PATCH`

    The time when the passphrase will expire, in ISO 8601 duration format or date and time format. The default is 1 hour.

    Example: P1DT2H3M4S or '2017-01-25T11:20:13Z'

  `generate_passphrase: bool POST PATCH`

    Auto generate a passphrase when true.

  `in_use: str GET POST PATCH`

    The in_use field of the cluster_peer_authentication.

    Valid choices:

    - ok
    - absent
    - revoked
  `passphrase: str GET POST PATCH`

    A password to authenticate the cluster peer relationship.

  `state: str GET`

    The state field of the cluster_peer_authentication.

    Valid choices:

    - ok
    - absent
    - pending
    - problem